# PrintNannyApiConfig


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**bearer_access_token** | **str** |  | [readonly] 
**base_path** | **str** |  | [readonly] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


